%global debug_package %{nil}

Name:           libflatarray
Version:        0.2.0
Release:        13%{?dist}
Summary:        C++ library for highly efficient multi-dimensional arrays
License:        Boost
URL:            http://www.libgeodecomp.org/libflatarray.html
Source0:        http://www.libgeodecomp.org/archive/libflatarray-%{version}.tar.bz2
Patch0:         https://github.com/gentryx/libflatarray/pull/1.patch
BuildRequires:  gcc-c++
BuildRequires:  boost-devel
BuildRequires:  cmake
ExclusiveArch:  %{ix86} x86_64

%description
LibFlatArray acts as a highly efficient multi-dimensional array of
arbitrary objects (array of structs, AoS), but really uses a struct of
arrays (SoA) memory layout. It's great for writing vectorized code and
its lightning-fast iterators give you access to neighboring elements
with zero address generation overhead.

Use cases include:
- computer simulations (e.g. stencil codes such as Lattice Boltzmann Methods)
- image processing (e.g. Gaussian filters)
- numerical methods (e.g. multiplication of complex matrices)

The library is written in C++ and uses templates to shift the burden
of address computation from runtime to compile time. It shares some
infrastructure with its parent project LibGeoDecomp.

%package        devel
Summary:        Development files for %{name}
#Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}

%description    devel
#This package contains libraries and header files for
This package contains header files for
developing applications that use %{name}.

%prep
%setup -q
%patch0 -p1
# Don't build examples.
sed -i '/examples/d' CMakeLists.txt

%build
# nVIDIA is what kind of open source?
%cmake -DWITH_CUDA=OFF
%make_build

%install
%make_install

%check
make check

%files devel
%doc AUTHORS README
%doc examples/
%license LICENSE
%{_includedir}/libflatarray/
%{_libdir}/cmake/libflatarray/

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 0.2.0-7
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.2.0-5
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Feb 01 2015 Christopher Meng <rpm@cicku.me> - 0.2.0-3
- Rework %%files section
- Turn off debuginfo
- Only build this for i686 and x86_64 due to Intel intrinsics

* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 0.2.0-2
- Rebuild for boost 1.57.0

* Sat Nov 15 2014 Christopher Meng <rpm@cicku.me> - 0.2.0-1
- Update to 0.2.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 0.1.1-2
- Rebuild for boost 1.55.0

* Sun Jan 26 2014 Christopher Meng <rpm@cicku.me> - 0.1.1-1
- Initial Package.
